from lib2to3.pgen2 import token
from nltk.tokenize import word_tokenize
import nltk
nltk.download('stopwords', quiet=True)
from nltk.corpus import stopwords
stopwords = list(stopwords.words('english'))
import contractions

def get_keywords(text):
    text = text.lower()
    text = ' '.join([contractions.fix(word) for word in text.split()])
    tokens = word_tokenize(text) 
    keyword_filter = lambda token: (not token in stopwords) and len(token) > 1 and token.isalpha()
    keywords = list(filter(keyword_filter, tokens))
    return keywords



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name='parrot-nlp',
    version='0.0.4',
    author='tsaruggan',
    author_email='tsaruggan@gmail.com',
    description='elegant NLP solutions and visualizations',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/tsaruggan/parrot',
    license='MIT',
    packages=['parrot'],
    install_requires=['requests'],
)

## Instructions:
# python3 -m build
# twine upload --skip-existing dist/*
# pip install parrot-nlp